@@ -76,12 +76,10 @@ class RotationPrefs(Configurator):
         self.__list.render()
 
 
-    def handle_CORE_EV_APP_STARTED(self):
+    def handle_COM_EV_APP_STARTED(self):
     
         o = config.orientation()
-        print "ORIENTATION", o
         if (o == config.ORIENTATION_PORTRAIT):
-            print "Startup in Portrait Mode"
             self.emit_message(msgs.ASR_EV_PORTRAIT)
 
 
