@@ -12,13 +12,13 @@ import gobject
 
 # some beautifications of places (table: path -> (name, info, icon))
 _BEAUTIFUL_PLACES = {
-    "/media/mmc1": ("SD card", "", theme.mb_folder_microsd),
-    "/home/user/MyDocs": ("My Documents", "", theme.mb_folder_mydocs),
-    "/media/mmc1/DCIM": ("Camera Folder", "", theme.mb_folder_dcim),
-    "/home/user/MyDocs/DCIM": ("Camera Folder", "", theme.mb_folder_dcim),
-    "/home/user/MyDocs/.sounds": ("Audio Clips", "", theme.mb_folder_audioclips),
-    "/home/user/MyDocs/.videos": ("Video Clips", "", theme.mb_folder_videoclips),
-    "/home/user/MyDocs/.images": ("Pictures", "", theme.mb_folder_imageclips),
+    "/media/mmc1": ("SD card", "Folder", theme.mb_folder_microsd),
+    "/home/user/MyDocs": ("My Documents", "Folder", theme.mb_folder_mydocs),
+    "/media/mmc1/DCIM": ("Camera Folder", "Folder", theme.mb_folder_dcim),
+    "/home/user/MyDocs/DCIM": ("Camera Folder", "Folder", theme.mb_folder_dcim),
+    "/home/user/MyDocs/.sounds": ("Audio Clips", "Folder", theme.mb_folder_audioclips),
+    "/home/user/MyDocs/.videos": ("Video Clips", "Folder", theme.mb_folder_videoclips),
+    "/home/user/MyDocs/.images": ("Pictures", "Folder", theme.mb_folder_imageclips),
 }
 
 
@@ -127,18 +127,20 @@ class LocalDevice(Device):
         item = File(self)
         item.is_local = True
         item.path = path
-        item.name = os.path.splitext(os.path.basename(path))[0]
         item.resource = path
         item.mtime = os.path.getmtime(path)
         item.parent = os.path.basename(os.path.dirname(path))
         if (os.path.isdir(item.resource)):
+            item.name = os.path.basename(path)
             item.acoustic_name = item.name + ", Folder"
             item.mimetype = item.DIRECTORY
+            item.info = "Folder"
             item.folder_flags = item.ITEMS_ENQUEUEABLE | \
                                 item.INDEXABLE | \
                                 item.ITEMS_SKIPPABLE
             
         else:
+            item.name = os.path.splitext(os.path.basename(path))[0]
             item.acoustic_name = os.path.splitext(item.name)[0]
             ext = os.path.splitext(path)[-1].lower()
             item.mimetype = mimetypes.lookup_ext(ext)
