@@ -7,6 +7,7 @@ from ui.Slider import Slider
 from ui.Toolbar import Toolbar
 from ui.dialog import OptionDialog
 from ui.layout import Arrangement
+from ui import windowflags
 from utils import mimetypes
 from utils import logging
 from mediabox import config as mb_config
@@ -99,6 +100,7 @@ class Navigator(Dialog):
         
     
         Dialog.__init__(self)
+        self.connect_key_pressed(self.__on_key_press)
 
         # browser list slider
         self.__browser_slider = Slider(theme.mb_list_slider)
@@ -112,27 +114,17 @@ class Navigator(Dialog):
         self.__browser.connect_folder_begin(self.__on_begin_folder)
         self.__browser.connect_folder_progress(self.__on_progress_folder)
         self.__browser.connect_folder_complete(self.__on_complete_folder)
-        #self.__browser.connect_file_added_to_library(self.__on_add_file_to_lib)
         self.__browser.connect_file_opened(self.__on_open_file)
-        #self.__browser.connect_file_enqueued(self.__on_enqueue_file)
-        #self.__browser.connect_file_bookmarked(self.__on_bookmark_file)
         self.__browser_slider.connect_button_pressed(
                                     lambda a,b:self.__browser.stop_scrolling())
-        #self.add(self.__browser)
 
         # [Add] button
         self.__btn_add = Button("Add New")
         self.__btn_add.set_visible(False)
         self.__btn_add.connect_clicked(self.__on_btn_add)
-        #self.add(self.__btn_add)
-
-        # beta version!
-        #self.__browser.add_overlay_renderer(self.__render_beta_mark)
-
 
         # toolbar
         self.__toolbar = Toolbar()
-        #self.add(self.__toolbar)
 
         self.__btn_home = ImageButton(theme.mb_btn_home_1,
                                       theme.mb_btn_home_2)
@@ -172,13 +164,6 @@ class Navigator(Dialog):
             self.__arr.set_xml(_LANDSCAPE_ARRANGEMENT)
 
 
-    def __render_beta_mark(self, screen):
-    
-        x, y = self.__browser.get_screen_pos()
-        w, h = self.__browser.get_size()
-        screen.draw_pixbuf(theme.mb_beta_mark, w - 128, h - 48)
-
-
     def __update_toolbar(self):
         """
         Updates the contents of the toolbar.
@@ -206,56 +191,26 @@ class Navigator(Dialog):
             
         self.__browser.invalidate()
         #self.__browser.render()
-
-
-
-    """
-    def __update_menu(self):
-        ""
-        Updates the contents of the window menu.
-        ""
-
-        cwd = self.__browser.get_current_folder()
-        opts = []
-        
-        opts.append((None, "Select Output Device", self.__on_menu_select_output))
-        
-        if (cwd.folder_flags & cwd.ITEMS_SORTABLE):
-            opts.append((None, "Rearrange", self.__on_menu_rearrange))
-            
-        opts.append((None, "Info", None))
-        
-        if (platforms.PLATFORM == platforms.MAEMO5):
-            opts.append((None, "FM Transmitter", self.__on_menu_fmtx))
-            
-        self.set_window_menu(*opts)
-    """
-    
-    
-    """
-    def show(self):
-    
-        SubView.show(self)
-        names = [ p.name for p in self.__browser.get_path() ]
-        #title = u" \u00bb ".join(names)
-        title = names[-1]
-        #self.set_title(title)
-
-        self.__update_toolbar()
-        #self.__update_menu()
-        self.emit_message(msgs.INPUT_EV_CONTEXT_BROWSER)
-    """
-    
+   
 
     def _visibility_changed(self):
         
         Dialog._visibility_changed(self)
         if (self.is_visible()):
             self.__tn_scheduler.resume()
+
+            if (not self.__browser.get_path()):
+                self.__browser.set_root_device(self.__root_dev)
+            
         else:
             self.__tn_scheduler.halt()
 
 
+    def __on_key_press(self, keycode):
+
+        self.call_service(msgs.INPUT_SVC_SEND_KEY, keycode, True)
+
+
     def __on_menu_select_output(self):
     
         self.emit_message(msgs.MEDIA_ACT_SELECT_OUTPUT, None)
@@ -293,15 +248,17 @@ class Navigator(Dialog):
         self.__tn_scheduler.halt()
         
         #self.set_title(f.name)
-        self.set_busy(True)
+        self.set_flag(windowflags.BUSY, True)
         
+        # show or hide [Add] button
         if (f.folder_flags & f.ITEMS_ADDABLE):
             self.__btn_add.set_visible(True)
         else:
             self.__btn_add.set_visible(False)
-                       
+            
         self.__update_layout()
         self.render()
+        
         self.__update_items_per_row(f)
 
 
@@ -321,7 +278,7 @@ class Navigator(Dialog):
 
     def __on_complete_folder(self, f):
 
-        self.set_busy(False)
+        self.set_flag(windowflags.BUSY, False)
         
         names = [ p.name for p in self.__browser.get_path() ]
         #title = u" \u00bb ".join(names)
@@ -337,39 +294,6 @@ class Navigator(Dialog):
         if (self.is_visible()):
             self.__tn_scheduler.resume()
 
-    """
-    def __on_add_file_to_lib(self, f):
-    
-        self.emit_message(msgs.LIBRARY_ACT_ADD_MEDIAROOT, f)
-        
-
-    def __on_enqueue_file(self, f):
-    
-        dlg = OptionDialog("Select a Playlist")
-        playlists = self.call_service(msgs.PLAYLIST_SVC_GET_LISTS)
-        print playlists
-        if (not playlists): return
-        
-        # select playlist
-        if (len(playlists) == 1):
-            playlist = playlists[0]
-        
-        else:
-            for pl in playlists:
-                dlg.add_option(None, pl)
-            if (dlg.run() == 0):
-                choice = dlg.get_choice()
-                playlist = playlists[choice]
-        #end for
-    
-        self.emit_message(msgs.PLAYLIST_ACT_APPEND, playlist, f)
-
-
-    def __on_bookmark_file(self, f):
-    
-        f.bookmarked = True
-    """
-
 
     def __update_thumbnail(self, item, thumbpath):
     
@@ -586,8 +510,9 @@ class Navigator(Dialog):
       
 
     def handle_CORE_EV_FOLDER_INVALIDATED(self, folder):
-    
-        self.__browser.invalidate_folder(folder)
+
+        if (self.is_visible()):
+            self.__browser.invalidate_folder(folder)
         if (folder and folder == self.__play_folder):
             self.__play_files = [ fl for fl in folder.get_children()
                                   if not fl.mimetype.endswith("-folder") ]
@@ -617,9 +542,10 @@ class Navigator(Dialog):
         #end if
 
     
-    def handle_CORE_EV_APP_STARTED(self):
+    def handle_COM_EV_APP_STARTED(self):
 
-        gobject.idle_add(self.__browser.set_root_device, self.__root_dev)
+        #gobject.idle_add(self.__browser.set_root_device, self.__root_dev)
+        pass
 
 
     def handle_CORE_EV_SEARCH_CLOSED(self):
@@ -653,110 +579,16 @@ class Navigator(Dialog):
     def handle_MEDIA_ACT_NEXT(self):
     
         self.__go_next()
-  
-          
-
-    def handle_INPUT_ACT_REPORT_CONTEXT(self):
-    
-        if (self.is_active()):
-            self.emit_message(msgs.INPUT_EV_CONTEXT_BROWSER)
 
 
+    def handle_INPUT_EV_UP(self, pressed):
 
-    def handle_INPUT_EV_UP(self):
-
-        if (not self.is_active()): return
-
-        now = time.time()
-        #if (now < self.__key_hold_down_timestamp + 0.1):
-        #    self.__skip_letter = True
-        #elif (now > self.__key_hold_down_timestamp + 0.5):
-        self.__skip_letter = False
-        self.__key_hold_down_timestamp = now
-
-        if (self.__is_searching):
-            idx = self.__browser.search(self.__search_term, -1)
-            if (idx != -1):
-                self.__browser.set_cursor(idx)
-                #self.__browser.scroll_to_item(idx)
-            
-        else:
-            self.__browser.move_cursor(-1, self.__skip_letter)
-            cursor = self.__browser.get_cursor()
-            item = self.__browser.get_item(cursor)
-            f = item.get_file()
-            self.emit_message(msgs.UI_ACT_TALK, f.acoustic_name or f.name)
-            
-
-    def handle_INPUT_EV_PAGE_UP(self):
-
-        if (self.is_active()):        
-            idx = self.__browser.get_index_at(0)
-            if (idx != -1):
-                new_idx = max(0, idx - 2)
-                self.__browser.scroll_to_item(new_idx)
+        if (self.is_enabled()):
+            self.__browser.move(0, -80)
 
 
-    def handle_INPUT_EV_DOWN(self):
+    def handle_INPUT_EV_DOWN(self, pressed):
 
-        if (not self.is_active()): return
-
-        now = time.time()
-        #if (now < self.__key_hold_down_timestamp + 0.1):
-        #    self.__skip_letter = True
-        #elif (now > self.__key_hold_down_timestamp + 0.5):
-        self.__skip_letter = False
-        self.__key_hold_down_timestamp = now
-        
-        if (self.__is_searching):
-            idx = self.__browser.search(self.__search_term, 1)
-            if (idx != -1):            
-                self.__browser.set_cursor(idx)
-                #self.__browser.scroll_to_item(idx)
-            
-        else:
-            self.__browser.move_cursor(1, self.__skip_letter)
-            cursor = self.__browser.get_cursor()
-            item = self.__browser.get_item(cursor)
-            f = item.get_file()
-            self.emit_message(msgs.UI_ACT_TALK, f.acoustic_name or f.name)
-
-
-
-    def handle_INPUT_EV_PAGE_DOWN(self):
-    
-        if (self.is_active()):
-            w, h = self.__browser.get_size()
-            idx = self.__browser.get_index_at(h)
-            if (idx != -1):
-                items = self.__browser.get_items()
-                new_idx = min(len(items), idx + 2)
-                self.__browser.scroll_to_item(new_idx)
-
-
-    def handle_INPUT_EV_RIGHT(self):
-    
-        if (self.is_active()):
-            self.select_tab(1)
-
-
-    def handle_INPUT_EV_ENTER(self):
-    
-        if (self.is_active()):
-            cursor = self.__browser.get_cursor()
-            if (cursor != -1):
-                self.__browser.trigger_item_button(cursor)
-
-    
-    def handle_INPUT_EV_GO_PARENT(self):
-    
-        if (self.is_active()):
-            self.__browser.go_parent()
-
-
-    def handle_INPUT_EV_MENU(self):
-    
-        #if (self.is_active()):
-        #self.emit_message(msgs.MEDIA_ACT_SELECT_OUTPUT, None)
-        self.emit_message(msgs.UI_ACT_SHOW_DIALOG, "FMTXDialog")
+        if (self.is_enabled()):
+            self.__browser.move(0, 80)
 
