@@ -101,6 +101,7 @@ class RootDevice(Device):
         self.__favorites = self.call_service(msgs.BOOKMARK_SVC_LIST, [])
         self.__favorites.sort(lambda a,b:cmp((a.device_id, a.name),
                                              (b.device_id, b.name)))
+        print "shelfed items", self.__favorites
         return self.__favorites
 
 
@@ -181,6 +182,11 @@ class RootDevice(Device):
 
         return options
 
+
+    def handle_COM_EV_APP_STARTED(self):
+    
+        self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, self.get_file("/"))
+
     
     def handle_CORE_EV_DEVICE_ADDED(self, ident, device):
 
@@ -189,8 +195,9 @@ class RootDevice(Device):
 
             if (device.TYPE in self.__device_lists):
                 self.__device_lists[device.TYPE].append(device)
-            
+
             folder = self.get_file(_TYPE_MAP[device.TYPE])
+            print "invalidating", folder, "due to", device
             self.emit_message(msgs.CORE_EV_FOLDER_INVALIDATED, folder)
         #end if
 
