@@ -335,7 +335,6 @@ class VideoPlayer(Player):
         self.__load_failed_handler = gobject.timeout_add(30000,
                                                          self.__on_load_failed)
         
-        uri = f.get_resource()
         try:
             self.__progress.set_message("Loading")
             self.__context_id = self.__player.load_video(f)
@@ -343,7 +342,7 @@ class VideoPlayer(Player):
         except:
             self.__progress.set_message("Error")
             logging.error("error loading media file: %s\n%s",
-                          uri, logging.stacktrace())
+                          f, logging.stacktrace())
 
 
     def handle_MEDIA_ACT_PAUSE(self):
@@ -375,23 +374,26 @@ class VideoPlayer(Player):
         self.render()
         
         
-    def handle_INPUT_EV_FULLSCREEN(self):
-    
-        self.__toggle_fullscreen()
+    def handle_INPUT_EV_FULLSCREEN(self, pressed):
+
+        if (self.is_enabled()):
+            self.__toggle_fullscreen()
 
 
-    def handle_INPUT_EV_VOLUME_UP(self):
-    
-        self.__volume = min(100, self.__volume + 5)
-        self.__volume_slider.set_value(self.__volume / 100.0)
-        if (self.__player):
-            self.__player.set_volume(self.__volume)
+    def handle_INPUT_EV_VOLUME_UP(self, pressed):
+
+        if (self.is_enabled()):
+            self.__volume = min(100, self.__volume + 5)
+            self.__volume_slider.set_value(self.__volume / 100.0)
+            if (self.__player):
+                self.__player.set_volume(self.__volume)
         
         
-    def handle_INPUT_EV_VOLUME_DOWN(self):
-    
-        self.__volume = max(0, self.__volume - 5)
-        self.__volume_slider.set_value(self.__volume / 100.0)
-        if (self.__player):
-            self.__player.set_volume(self.__volume)
+    def handle_INPUT_EV_VOLUME_DOWN(self, pressed):
+
+        if (self.is_enabled()):
+            self.__volume = max(0, self.__volume - 5)
+            self.__volume_slider.set_value(self.__volume / 100.0)
+            if (self.__player):
+                self.__player.set_volume(self.__volume)
 
