@@ -10,6 +10,7 @@ from io import Downloader
 from io import FileDownloader
 from io import FileServer
 from mediabox import values
+import platforms
 import formats
 import config
 from theme import theme
@@ -48,6 +49,8 @@ _PAGE_SIZE = 25
 _STAR_CHAR = u"\u2606"
 _STAR2_CHAR = u"\u2605"
 
+_N900_FORMAT_WHITELIST = [5, 6, 13, 17, 18]
+
 
 class _SearchContext(object):
 
@@ -268,6 +271,9 @@ class YouTube(Device):
                 # read total number of hits
                 total_results = int(node.get_pcdata())
                 
+                # set a sane limit (YouTube cannot handle more anyway)
+                total_results = min(total_results, 40 * _PAGE_SIZE)
+                
                 page = 1
                 for n in range(1, total_results, _PAGE_SIZE):
                     f = File(self)
@@ -284,7 +290,6 @@ class YouTube(Device):
                 
             return True
     
-    
         MiniXML(xml, callback = on_receive_node)
     
     
@@ -309,7 +314,7 @@ class YouTube(Device):
                 else:
                     #f.info = "%d:%02d, %s, %d views\nby %s" \
                     f.info = "by %s\n" \
-                             "Duration: %d:%02d\tViews: %d\n" \
+                             "Duration: %d:%02d\tViews: %d\t" \
                              "Rating: %s" \
                              % (entry.authors,
                                 mins, secs, entry.view_count,
@@ -430,12 +435,12 @@ class YouTube(Device):
 
         if (not query):
             # present search dialog
-            dlg = InputDialog("Search")
+            dlg = InputDialog("Search", label_ok = "Search")
             dlg.add_input("Keywords:", "")
-            dlg.run()
+            resp = dlg.run()
             values = dlg.get_values()
 
-            if (values):
+            if (resp == dlg.RETURN_OK and values):
                 query = urllib.quote_plus(values[0])
             else:
                 cb(None, *args)
@@ -563,7 +568,7 @@ class YouTube(Device):
                 #end if
             #end if
 
-        
+
         # handle locally saved videos
         if (f.resource.startswith("/")): return f.resource
         
@@ -572,19 +577,25 @@ class YouTube(Device):
                               "This video is not available in your country.")
             return ""
         
-        #self.emit_message(msgs.UI_ACT_SHOW_MESSAGE,
-        #                 "Requesting Video %s" % f.name)
-            
         try:
             flv, fmts = self.__get_flv(f.resource)
         except:
             logging.error("could not retrieve video\n%s", logging.stacktrace())
-            #self.emit_message(msgs.UI_ACT_HIDE_MESSAGE)
             return ""
 
-        # download high-quality version, if desired
-        qtype = config.get_quality_type()
-        print "QType:", qtype, fmts, qtype in fmts
+        # filter out incompatible formats
+        if (platforms.MAEMO5):
+            fmts = [ fmt for fmt in fmts if fmt in _N900_FORMAT_WHITELIST ]
+
+        # retrieve high-quality version, if desired
+        if (len(fmts) > 1):
+            qtype = self.__ask_for_quality(fmts)
+        else:
+            qtype = 0
+
+        print "Requested Video Quality:", qtype
+
+        #qtype = config.get_quality_type()
         if (qtype in fmts):
             flv = flv + "&fmt=%d" % qtype
             ext = "." + formats.get_container(qtype)
@@ -602,6 +613,9 @@ class YouTube(Device):
         keep_path = os.path.join(cache_folder, _VIDEO_FOLDER,
                                  self.__make_filename(f.name, ext))
         self.__keep_video = False
+        return flv + "&ext=" + ext
+
+        """
         self.__flv_downloader = FileDownloader(flv, flv_path, on_dload,
                                                flv_path, keep_path)
         
@@ -613,6 +627,37 @@ class YouTube(Device):
         self.__fileserver.allow(flv_path, "/" + f.resource + ".flv")
         
         return self.__fileserver.get_location() + "/" + f.resource + ".flv"
+        """
+
+
+    def __ask_for_quality(self, fmts):
+
+        dlg = OptionDialog("Choose Quality Version")
+        for fmt in fmts:
+            dlg.add_option(None, formats.get_description(fmt))
+        resp = dlg.run()
+
+        if (dlg.get_choice() != -1):
+            return fmts[dlg.get_choice()]
+        else:
+            return 0
+
+
+    def __on_download(self, folder, f):
+
+        uri = f.get_resource()
+        filename = self.__make_filename(f.name, "flv")
+        print "DOWNLOAD:", filename
+
+
+    """
+    def get_file_actions(self, folder, f):
+
+        actions = Device.get_file_actions(self, folder, f)
+        actions.append((None, "Download", self.__on_download))
+
+        return actions
+    """
 
 
     def delete_file(self, folder, idx):
