@@ -39,10 +39,7 @@ class StorageBrowser(ThumbableGridView):
 
         # timestamp of the last list rendering
         self.__last_list_render_time = 0
-       
-        # callback for loading thumbnails
-        self.__thumbnailer = lambda *f:None
-        
+              
         # the currently hilighted file
         self.__hilighted_file = None
         
@@ -235,19 +232,7 @@ class StorageBrowser(ThumbableGridView):
         
         root = device.get_root()
         gobject.idle_add(self.load_folder, root, self.GO_NEW)
-        
-        
-    def set_thumbnailer(self, cb):
-        """
-        Sets a callback function for providing thumbnails.
-        
-        Signature of the callback: C{(f, cb, *args)}
-        
-        @param cb: callback function
-        """
-    
-        self.__thumbnailer = cb
-        
+              
         
     def begin_bulk_operation(self):
         """
@@ -290,7 +275,7 @@ class StorageBrowser(ThumbableGridView):
         
     def get_current_folder(self):
         """
-        Returns the File object of the current folder, or None if there the
+        Returns the File object of the current folder, or None if the
         path is empty.
         
         @return: File object representing the current folder
@@ -425,7 +410,6 @@ class StorageBrowser(ThumbableGridView):
         self.set_cursor(cursor)
         
         
-        
     def go_root(self):
         """
         Goes all the way up to the root folder.
@@ -453,7 +437,7 @@ class StorageBrowser(ThumbableGridView):
         """
         
         if (self.get_current_folder()):
-            self.load_folder(self.get_current_folder(), self.GO_PARENT)
+            self.load_folder(self.get_current_folder(), self.GO_NEW)
         
         
     def load_folder(self, folder, direction, force_reload = False):
@@ -465,7 +449,6 @@ class StorageBrowser(ThumbableGridView):
         @param force_reload: whether to force reloading the folder
         """
 
-
         # are we just reloading the same folder?
         reload_only = False
         if (self.__path_stack):
@@ -526,7 +509,7 @@ class StorageBrowser(ThumbableGridView):
         # load remaining items
         loading_status = self.__path_stack[-1][1]
         if (loading_status == _STATUS_INCOMPLETE or full_reload):
-            self.set_message("Loading")
+            #self.set_message("Loading")
             self.complete_current_folder()
         else:
             self.emit_event(self.EVENT_FOLDER_COMPLETE, folder)
@@ -543,13 +526,12 @@ class StorageBrowser(ThumbableGridView):
 
         def on_child(f, token, path, entries):
             # abort if the user has changed the directory inbetween
-            #if (self.get_current_folder() != path): return False
             if (token != self.__token): return False
-            
+
             if (f):
                 #self.get_item(0).set_info("%d items" \
                 #                          % len(self.get_files()))
-                self.set_message("Loading (%d items)" % len(self.get_files()))
+                #self.set_message("Loading") # (%d items)" % len(self.get_files()))
                 #self.invalidate_item(0)
                 entries.append(f)
                 try:
@@ -559,11 +541,6 @@ class StorageBrowser(ThumbableGridView):
                 except:
                     print logging.stacktrace()
 
-                import gtk
-                gobject.timeout_add(1, lambda : False)
-                gtk.main_iteration(True)
-
-
             else:
                 #self.get_item(0).set_info("%d items" % len(self.get_files()))
                 #self.invalidate_item(0)
@@ -576,28 +553,36 @@ class StorageBrowser(ThumbableGridView):
                 self.__path_stack[-1][1] = _STATUS_OK
                 
                 self.invalidate()
-                #self.render()
                 self.emit_event(self.EVENT_FOLDER_COMPLETE,
                                 self.get_current_folder())
-                #self.send_event(self.EVENT_FOLDER_OPENED,
-                #                self.get_current_folder())
 
                 # now is a good time to collect garbage
                 import gc; gc.collect()    
-
-
-            now = time.time()
-            items_count = len(self.get_files())
-            if (not f or (items_count > 10 and now > self.__last_list_render_time + 0.5)):
-                self.__last_list_render_time = now
-                #self.invalidate_buffer()
-                self.render()
-
-                if (not f):
-                    return False
             #end if
-            
-            return True
+
+            # give visual feedback while loading the visible part of a folder
+            if (not f or len(entries) in (8, 16)):
+                self.invalidate()
+                self.render()
+            #end if
+
+            # don't block UI while loading non-local folders
+            import gtk
+            #now = time.time()
+            #if (gtk.events_pending()): # or 
+            #    now > self.__last_list_render_time + 0.5):
+           
+                #self.__last_list_render_time = now
+
+            while (gtk.events_pending()):
+                gtk.main_iteration(False)
+
+            if (not f):
+                # last item has been reached
+                return False
+            else:
+                # continue loading next item
+                return True
 
 
         cwd = self.get_current_folder()
@@ -629,7 +614,6 @@ class StorageBrowser(ThumbableGridView):
     
         self.append_item(item)
 
-
         idx = len(self.get_items()) - 1
 
         #if (not cwd.folder_flags & cwd.ITEMS_SORTED_ALPHA):
@@ -639,4 +623,3 @@ class StorageBrowser(ThumbableGridView):
         if (self.__hilighted_file == f):
             self.set_hilight(idx)
         self.invalidate_item(idx)
-
