@@ -25,7 +25,7 @@ def _get_colormap_and_depth():
 
     screen = gtk.gdk.screen_get_default()
     try:
-        have_rgba = screen.is_composited()
+        have_rgba = False #screen.is_composited()
     except:
         have_rgba = False
     if (have_rgba):
@@ -135,6 +135,7 @@ class Pixmap(object):
             self.__pixmap = pmap
             self.__buffered = True
             self.__create_buffer()
+            w, h = pmap.get_size()
         else:
             self.__pixmap = gtk.gdk.Pixmap(None, w, h, _DEPTH)
             self.__buffered = False
@@ -228,11 +229,11 @@ class Pixmap(object):
         cmap, depth = _get_colormap_and_depth()
         
         new_pmap = gtk.gdk.Pixmap(None, w, h, depth)
-        self.__gc = new_pmap.new_gc()
         self.__cmap = new_pmap.get_colormap() or cmap
         new_pmap.set_colormap(self.__cmap)
         del self.__pixmap
         self.__pixmap = new_pmap
+        self.__gc = self.__pixmap.new_gc()
         if (_HAVE_CAIRO):
             self.__cairo_ctx = self.__pixmap.cairo_create()
 
@@ -531,7 +532,7 @@ class Pixmap(object):
         _reload(font, color)
         self.__layout.set_font_description(font)
         self.__layout.set_width(w * pango.SCALE)
-        self.__layout.set_justify(True)
+        #self.__layout.set_justify(True)
         self.__layout.set_alignment(align_map.get(alignment, pango.ALIGN_LEFT))
         self.__layout.set_text("")
         self.__layout.set_markup("")
